Install with `pip install yeonji`

# borgsize

Lists sizes of all backups in a borg repository. Type `borgsize *repopath*`, e.g. `borgsize ~/myrepos/coolrepo`.

# flacco

Flacco is a simple tool for organizing CD rips from cdparanoia. It renames the flac files (or converts from wav files) and tags them with the desired title in one step. Type `flacco *num* *title*`, e.g. `flacco 1 "As If It's Your Last"`.

[AUR](https://aur.archlinux.org/packages/flacco/)

# ytdlj

Merges any number of local files / youtube videos into a new file. Type `ytdlj *URLs/files* *outputname*`, e.g. `ytdlj party1.mkv ../party2.mkv https://www.youtube.com/watch?v=b3_lVSrPB6w fullvideo.mkv`.

# me2dlc

Installs ME2 DLCs from exe files on Linux using Steam Proton. Navigate to directory with files, then run `me2dlc`. Requires protontricks.

# ytd

Quickly downloads videos to predefined locations. Use `ytd *preset* *URL*` to download and `ytd --new *preset* --path *path*` to define new preset.
